from datetime import datetime
from fastapi import FastAPI, status
from fastapi.staticfiles import StaticFiles
from sqlmodel import ARRAY, Column, SQLModel, Field, Session, String, create_engine
from fastapi.middleware.cors import CORSMiddleware
import uvicorn

with open("db.secrets", "r") as f:
    db_secrets = f.readline().strip()


app = FastAPI(title="cutt")
engine = create_engine(db_secrets)
# SQLModel.metadata.create_all(engine)
origins = [
    "*",
    "http://localhost",
    "http://localhost:3000",
    "http://localhost:8000",
]

app.add_middleware(
    CORSMiddleware,
    allow_origins=origins,
    allow_credentials=True,
    allow_methods=["*"],
    allow_headers=["*"],
)


class Chemistry(SQLModel, table=True):
    id: int | None = Field(default=None, primary_key=True)
    time: datetime | None = Field(default_factory=datetime.now)
    user: str
    love: list[str] = Field(sa_column=Column(ARRAY(String)))
    hate: list[str] = Field(sa_column=Column(ARRAY(String)))
    undecided: list[str] = Field(sa_column=Column(ARRAY(String)))


@app.post("/chemistry/", status_code=status.HTTP_200_OK)
def submit_chemistry(chemistry: Chemistry):
    with Session(engine) as session:
        session.add(chemistry)
        session.commit()


app.mount("/", StaticFiles(directory="dist", html=True), name="site")

# if __name__ == "__main__":
#     uvicorn.run("main:app", workers=1, port=8000, host="0.0.0.0")
